.. _Issue Tracker: https://github.com/isomeric/isomer/issues
.. _FreeNode IRC Network: http://freenode.net
.. _IRC Channel: http://webchat.freenode.net/?randomnick=1&channels=hackerfleet&uio=d4


Development Introduction
========================


Here's how we do things in Isomer...


Communication
-------------

- `IRC Channel`_ on the `FreeNode IRC Network`_
- `Issue Tracker`_


.. note:: If you are familiar with `IRC <http://en.wikipedia.org/wiki/Internet_Relay_Chat>`_
        and use your own IRC Client then connect to the FreeNode Network and ``/join #hackerfleet``.


Standards
---------

We use the following coding standard:

- `PEP-008 <http://www.python.org/dev/peps/pep-0008/>`_

We also lint our codebase with the following tools:

- `pyflakes <https://pypi.python.org/pypi/pyflakes>`_
- `pep8 <https://pypi.python.org/pypi/pep8>`_
- `mccabe <https://pypi.python.org/pypi/mccabe/0.2.1>`_

Please ensure your Development IDE or Editor has the above
linters and checkers in place and enabled.

Alternatively you can use the following command line tool:

- `flake8 <https://pypi.python.org/pypi/flake8>`_


Tools
-----

We use the following tools to develop Isomer and share code:

- **Code Sharing:**
  `Git <https://git-scm.com/>`_
- **Code Hosting and Bug Reporting:**
  `GitHub <https://github.com/isomeric/isomer>`_
- **Issue Tracker:**
  `Issue Tracker <https://github.com/isomeric/isomer/issues>`_
- **Documentation Hosting:**
  `Read the Docs <http://isomer.readthedocs.org>`_
- **Package Hosting:**
  `Python Package Index (PyPi) <http://pypi.python.org/pypi/isomer>`_
- **Docker Hub Automated Builds:**
  `Dockerhub <https://hub.docker.com/r/isomeric/isomer/>`_
- **Continuous Integration:**
  `Travis CI <https://travis-ci.org/isomeric/isomer>`_
- **Code Quality:**
  `Landscape <https://landscape.io/github/isomeric/isomer/>`_
- **Frontend Testing:**
  `Browserstack <https://browserstack.com>`_
- **Translations:**
  `Transifex <https://www.transifex.com/hackerfleet-community/isomer/>`__

We strongly suggest familiarizing with all of them, to make sure you understand our CI.

Big thanks to all of these magnificent and free-for-opensource services!
